@@ -15,7 +15,7 @@
     <message>
         <location filename="src/AboutView.cpp" line="26"/>
         <source>%1 is Free Software but its development takes precious time.</source>
-        <translation>%1 és Software Lliure però el seu desenvolupament pren un temps preciós.</translation>
+        <translation>%1 és programari lliure, però el seu desenvolupament pren un temps preciós.</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="27"/>
@@ -43,42 +43,27 @@
         <translation>Traduïu el %1 al vostre idioma natal utilitzant %2</translation>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="48"/>
-        <source>Report bugs and send in your ideas to %1</source>
-        <translation>Informeu d&apos;errors i envieu les vostres idees a %1</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="52"/>
+        <location filename="src/AboutView.cpp" line="49"/>
         <source>Icon designed by %1.</source>
         <translation>Icona dissenyada per %1.</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="53"/>
-        <source>Compact mode contributed by %1.</source>
-        <translation>Mode compacte aportat per %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="54"/>
-        <source>HTTP proxy support contributed by %1.</source>
-        <translation>Suport de servidor intermediari HTTP aportat per %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="58"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Alliberat sota la &lt;a href=&apos;%1&apos;&gt;Llicència Pública General de GNU&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="70"/>
+        <location filename="src/AboutView.cpp" line="65"/>
         <source>&amp;Close</source>
         <translation>&amp;Tanca</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="18"/>
+        <location filename="src/AboutView.h" line="25"/>
         <source>About</source>
         <translation>Quant a</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="20"/>
+        <location filename="src/AboutView.h" line="27"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>El que sempre havíeu volgut saber sobre el %1 i mai us havíeu atrevit a preguntar</translation>
     </message>
@@ -132,47 +117,47 @@
 <context>
     <name>DownloadItem</name>
     <message>
-        <location filename="src/downloaditem.cpp" line="299"/>
+        <location filename="src/downloaditem.cpp" line="308"/>
         <source>bytes</source>
         <translation>bytes</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="302"/>
+        <location filename="src/downloaditem.cpp" line="311"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="305"/>
+        <location filename="src/downloaditem.cpp" line="314"/>
         <source>MB</source>
         <translation>MB</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="321"/>
+        <location filename="src/downloaditem.cpp" line="330"/>
         <source>bytes/sec</source>
-        <translation>bytes/seg</translation>
-    </message>
-    <message>
-        <location filename="src/downloaditem.cpp" line="324"/>
-        <source>KB/sec</source>
-        <translation>KB/seg</translation>
-    </message>
-    <message>
-        <location filename="src/downloaditem.cpp" line="327"/>
-        <source>MB/sec</source>
-        <translation>MB/seg</translation>
+        <translation>bytes/s</translation>
     </message>
     <message>
         <location filename="src/downloaditem.cpp" line="333"/>
+        <source>KB/sec</source>
+        <translation>KB/s</translation>
+    </message>
+    <message>
+        <location filename="src/downloaditem.cpp" line="336"/>
+        <source>MB/sec</source>
+        <translation>MB/s</translation>
+    </message>
+    <message>
+        <location filename="src/downloaditem.cpp" line="342"/>
         <source>seconds</source>
         <translation>segons</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="336"/>
+        <location filename="src/downloaditem.cpp" line="345"/>
         <source>minutes</source>
         <translation>minuts</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="339"/>
+        <location filename="src/downloaditem.cpp" line="348"/>
         <source>%4 %5 remaining</source>
         <translation>%4 %5 restant</translation>
     </message>
@@ -252,12 +237,12 @@
     <message>
         <location filename="src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
-        <translation>Pausa</translation>
+        <translation>Posa en pausa</translation>
     </message>
     <message>
         <location filename="src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
-        <translation>Reprodueix/Pausa</translation>
+        <translation>Reprodueix/posa en pausa</translation>
     </message>
     <message>
         <location filename="src/globalshortcuts.cpp" line="19"/>
@@ -292,7 +277,7 @@
     <message>
         <location filename="src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
-        <translation>Silenci</translation>
+        <translation>Silencia</translation>
     </message>
     <message>
         <location filename="src/globalshortcuts.cpp" line="26"/>
@@ -308,22 +293,22 @@
 <context>
     <name>ListModel</name>
     <message>
-        <location filename="src/ListModel.cpp" line="47"/>
+        <location filename="src/ListModel.cpp" line="51"/>
         <source>Searching...</source>
-        <translation>Buscant...</translation>
+        <translation>S&apos;està cercant...</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="48"/>
+        <location filename="src/ListModel.cpp" line="52"/>
         <source>Show %1 More</source>
         <translation>Mostra %1 Més</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="49"/>
+        <location filename="src/ListModel.cpp" line="53"/>
         <source>No videos</source>
         <translation>Cap vídeo</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="50"/>
+        <location filename="src/ListModel.cpp" line="54"/>
         <source>No more videos</source>
         <translation>Cap més vídeo</translation>
     </message>
@@ -339,453 +324,492 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="src/MainWindow.cpp" line="125"/>
+        <location filename="src/MainWindow.cpp" line="160"/>
         <source>&amp;Stop</source>
         <translation>&amp;Atura</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="126"/>
+        <location filename="src/MainWindow.cpp" line="161"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Atura la reproducció i torna a la vista de búsqueda</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="132"/>
+        <location filename="src/MainWindow.cpp" line="179"/>
         <source>S&amp;kip</source>
         <translation>&amp;Salta</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="133"/>
+        <location filename="src/MainWindow.cpp" line="180"/>
         <source>Skip to the next video</source>
         <translation>Salta al vídeo següent</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="139"/>
-        <location filename="src/MainWindow.cpp" line="740"/>
+        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="835"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pausa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="140"/>
-        <location filename="src/MainWindow.cpp" line="741"/>
+        <location filename="src/MainWindow.cpp" line="187"/>
+        <location filename="src/MainWindow.cpp" line="836"/>
         <source>Pause playback</source>
         <translation>Pausa la reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="146"/>
+        <location filename="src/MainWindow.cpp" line="193"/>
         <source>&amp;Full Screen</source>
-        <translation>Pantalla &amp;Completa</translation>
+        <translation>Pantalla &amp;completa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="147"/>
+        <location filename="src/MainWindow.cpp" line="194"/>
         <source>Go full screen</source>
         <translation>Passa a pantalla completa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="162"/>
-        <source>&amp;Compact mode</source>
-        <translation>&amp;Mode compacte</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="163"/>
+        <location filename="src/MainWindow.cpp" line="210"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Amaga la llista de reproducció i la barra d&apos;eines</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="171"/>
-        <source>Open the &amp;YouTube page</source>
-        <translation>Obre la pàgina de &amp;YouTube</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="172"/>
+        <location filename="src/MainWindow.cpp" line="223"/>
         <source>Go to the YouTube video page and pause playback</source>
-        <translation>Ves a la pàgina del vídeo de YouTube i pausa la reproducció</translation>
+        <translation>Ves a la pàgina del vídeo del YouTube i pausa la reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="178"/>
-        <source>Copy the YouTube &amp;link</source>
-        <translation>Copia l&apos;&amp;enllaç de YouTube</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="179"/>
+        <location filename="src/MainWindow.cpp" line="230"/>
         <source>Copy the current video YouTube link to the clipboard</source>
-        <translation>Copia l&apos;enllaç del vídeo actual de YouTube al porta-retalls</translation>
+        <translation>Copia l&apos;enllaç del vídeo actual del YouTube al porta-retalls</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="185"/>
-        <source>Copy the video stream &amp;URL</source>
-        <translation>Copia el &amp;URL del flux de vídeo</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="237"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>Copia el URL del flux de vídeo actual al porta-retalls</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="192"/>
-        <source>Find video &amp;parts</source>
-        <translation>Troba &amp;parts del vídeo</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="193"/>
+        <location filename="src/MainWindow.cpp" line="244"/>
         <source>Find other video parts hopefully in the right order</source>
         <translation>Troba altres parts del vídeo, amb sort en l&apos;ordre correcte</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="199"/>
+        <location filename="src/MainWindow.cpp" line="250"/>
         <source>&amp;Remove</source>
         <translation>&amp;Elimina</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="200"/>
+        <location filename="src/MainWindow.cpp" line="251"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Elimina els vídeos seleccionats de la llista de reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="206"/>
+        <location filename="src/MainWindow.cpp" line="257"/>
         <source>Move &amp;Up</source>
-        <translation>Mou &amp;Amunt</translation>
+        <translation>Mou &amp;amunt</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="207"/>
+        <location filename="src/MainWindow.cpp" line="258"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Mou amunt els vídeos seleccionats en la llista de reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="213"/>
+        <location filename="src/MainWindow.cpp" line="264"/>
         <source>Move &amp;Down</source>
-        <translation>Mou A&amp;vall</translation>
+        <translation>Mou a&amp;vall</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="214"/>
+        <location filename="src/MainWindow.cpp" line="265"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Mou avall els vídeos seleccionats en la llista de reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="220"/>
-        <source>&amp;Clear recent searches</source>
-        <translation>&amp;Neteja búsquedes recents</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="225"/>
+        <location filename="src/MainWindow.cpp" line="276"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>Neteja l&apos;historial de búsquedes. No es pot desfer.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="230"/>
+        <location filename="src/MainWindow.cpp" line="281"/>
         <source>&amp;Quit</source>
         <translation>&amp;Surt</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="232"/>
-        <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="233"/>
+        <location filename="src/MainWindow.cpp" line="284"/>
         <source>Bye</source>
         <translation>Adéu</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="237"/>
+        <location filename="src/MainWindow.cpp" line="288"/>
         <source>&amp;Website</source>
-        <translation>Pàgina &amp;Web</translation>
+        <translation>Pàgina &amp;web</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="239"/>
+        <location filename="src/MainWindow.cpp" line="290"/>
         <source>%1 on the Web</source>
-        <translation>%1 en la Web</translation>
+        <translation>%1 a la xarxa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="244"/>
-        <source>Make a &amp;donation</source>
-        <translation>Fer una &amp;donació</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="245"/>
+        <location filename="src/MainWindow.cpp" line="296"/>
         <source>Please support the continued development of %1</source>
         <translation>Siusplau ajuda al desenvolupament continuat del %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="250"/>
+        <location filename="src/MainWindow.cpp" line="301"/>
         <source>&amp;About</source>
         <translation>&amp;Quant a</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="252"/>
+        <location filename="src/MainWindow.cpp" line="303"/>
         <source>Info about %1</source>
         <translation>Info sobre %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="260"/>
+        <location filename="src/MainWindow.cpp" line="311"/>
         <source>Search</source>
-        <translation>Busca</translation>
+        <translation>Cerca</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="279"/>
+        <location filename="src/MainWindow.cpp" line="330"/>
         <source>Mute volume</source>
-        <translation>Silencia volum</translation>
+        <translation>Silencia el volum</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="281"/>
-        <source>Ctrl+M</source>
-        <translation>Ctrl+M</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="312"/>
-        <location filename="src/MainWindow.cpp" line="1091"/>
+        <location filename="src/MainWindow.cpp" line="359"/>
+        <location filename="src/MainWindow.cpp" line="1179"/>
         <source>&amp;Downloads</source>
         <translation>&amp;Baixades</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="313"/>
+        <location filename="src/MainWindow.cpp" line="360"/>
         <source>Show details about video downloads</source>
         <translation>Mostra detalls de les descàrregues de vídeo</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="321"/>
+        <location filename="src/MainWindow.cpp" line="368"/>
         <source>&amp;Download</source>
         <translation>&amp;Baixa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="322"/>
+        <location filename="src/MainWindow.cpp" line="369"/>
         <source>Download the current video</source>
         <translation>Baixa el vídeo actual</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="334"/>
+        <location filename="src/MainWindow.cpp" line="381"/>
         <source>Share the current video using %1</source>
         <translation>Comparteix el vídeo actual fent servir %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="346"/>
+        <location filename="src/MainWindow.cpp" line="393"/>
         <source>&amp;Email</source>
         <translation>&amp;Email</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="347"/>
+        <location filename="src/MainWindow.cpp" line="394"/>
         <source>Email</source>
         <translation>Correu electrònic</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="382"/>
+        <location filename="src/MainWindow.cpp" line="398"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Tanca</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="403"/>
+        <source>&amp;Float on Top</source>
+        <translation>Manté a &amp;sobre</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="408"/>
+        <source>&amp;Stop After This Video</source>
+        <translation>&amp;Atura després d&apos;aquest vídeo</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="445"/>
         <source>&amp;Application</source>
         <translation>&amp;Aplicació</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="390"/>
+        <location filename="src/MainWindow.cpp" line="447"/>
+        <source>Buy %1...</source>
+        <translation>Compra %1...</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="458"/>
         <source>&amp;Playback</source>
         <translation>&amp;Reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="400"/>
+        <location filename="src/MainWindow.cpp" line="472"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Llista de reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="407"/>
+        <location filename="src/MainWindow.cpp" line="479"/>
         <source>&amp;Video</source>
         <translation>&amp;Vídeo</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="421"/>
+        <location filename="src/MainWindow.cpp" line="490"/>
         <source>&amp;View</source>
         <translation>&amp;Vista</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="427"/>
+        <location filename="src/MainWindow.cpp" line="497"/>
         <source>&amp;Share</source>
         <translation>&amp;Compartir</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="435"/>
+        <location filename="src/MainWindow.cpp" line="509"/>
         <source>&amp;Help</source>
         <translation>A&amp;juda</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="520"/>
+        <location filename="src/MainWindow.cpp" line="586"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation>Prem %1 per pujar el volum, %2 per baixar-lo</translation>
+        <translation>Premeu %1 per pujar el volum, %2 per baixar-lo</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="669"/>
-        <location filename="src/MainWindow.cpp" line="675"/>
+        <location filename="src/MainWindow.cpp" line="748"/>
+        <location filename="src/MainWindow.cpp" line="754"/>
         <source>Opening %1</source>
         <translation>Obrint %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="688"/>
+        <location filename="src/MainWindow.cpp" line="787"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>Vol abandonar el %1 amb una baixada en curs?</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="689"/>
+        <location filename="src/MainWindow.cpp" line="788"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>Si tanca el %1 ara, aquesta baixada es cancel·larà.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="692"/>
+        <location filename="src/MainWindow.cpp" line="793"/>
         <source>Close and cancel download</source>
         <translation>Tanca i cancel·la la baixada</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="693"/>
+        <location filename="src/MainWindow.cpp" line="794"/>
         <source>Wait for download to finish</source>
         <translation>Espera a acabar la baixada</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="854"/>
+        <location filename="src/MainWindow.cpp" line="940"/>
         <source>Leave &amp;Full Screen</source>
         <translation>Abandona la Pantalla &amp;Completa</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1195"/>
+        <location filename="src/MainWindow.cpp" line="1283"/>
         <source>%1 version %2 is now available.</source>
         <translation>%1 versió %2 ja està disponible.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1201"/>
+        <location filename="src/MainWindow.cpp" line="1297"/>
         <source>Remind me later</source>
         <translation>Recorda-m&apos;ho més tard</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1207"/>
-        <location filename="src/MainWindow.cpp" line="1213"/>
+        <location filename="src/MainWindow.cpp" line="1294"/>
         <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
         <translation>Per obtenir la versió actualitzada, descarregueu el %1 de nou des de l&apos;enllaç que vau rebre per correu electrònic i torneu-lo a instal·lar.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1216"/>
+        <location filename="src/MainWindow.cpp" line="1301"/>
         <source>Update</source>
         <translation>Actualitza</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="733"/>
+        <location filename="src/MainWindow.cpp" line="828"/>
         <source>Error: %1</source>
         <translation>Error: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="756"/>
+        <location filename="src/MainWindow.cpp" line="169"/>
+        <source>P&amp;revious</source>
+        <translation>P&amp;revi</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="170"/>
+        <source>Go back to the previous track</source>
+        <translation>Torna a la pista anterior</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="209"/>
+        <source>&amp;Compact Mode</source>
+        <translation>&amp;Mode compacte</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="222"/>
+        <source>Open the &amp;YouTube Page</source>
+        <translation>Obre la pàgina de &amp;YouTube</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="229"/>
+        <source>Copy the YouTube &amp;Link</source>
+        <translation>Copia l&apos;&amp;enllaç de YouTube</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="236"/>
+        <source>Copy the Video Stream &amp;URL</source>
+        <translation>Copia el &amp;URL del flux de vídeo</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="243"/>
+        <source>Find Video &amp;Parts</source>
+        <translation>Troba &amp;parts de vídeo</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="271"/>
+        <source>&amp;Clear Recent Searches</source>
+        <translation>&amp;Neteja les búsquedes recents</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="295"/>
+        <source>Make a &amp;Donation</source>
+        <translation>Fer una &amp;donació</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="352"/>
+        <source>&amp;Manually Start Playing</source>
+        <translation>Reprodueix vídeos &amp;manualment</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="353"/>
+        <source>Manually start playing videos</source>
+        <translation>Comença a reproduir vídeos manualment</translation>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="848"/>
         <source>&amp;Play</source>
         <translation>&amp;Reprodueix</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="757"/>
+        <location filename="src/MainWindow.cpp" line="849"/>
         <source>Resume playback</source>
         <translation>Continua la reproducció</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="964"/>
+        <location filename="src/MainWindow.cpp" line="1055"/>
         <source>Remaining time: %1</source>
         <translation>Temps restant: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1022"/>
+        <location filename="src/MainWindow.cpp" line="1113"/>
         <source>Volume at %1%</source>
         <translation>Volum al %1%</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1028"/>
+        <location filename="src/MainWindow.cpp" line="1119"/>
         <source>Volume is muted</source>
-        <translation>Volum silenciat</translation>
+        <translation>El volum està silenciat</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1031"/>
+        <location filename="src/MainWindow.cpp" line="1122"/>
         <source>Volume is unmuted</source>
-        <translation>Volum de-silenciat</translation>
+        <translation>El volum no està silenciat</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1038"/>
+        <location filename="src/MainWindow.cpp" line="1129"/>
         <source>Maximum video definition set to %1</source>
         <translation>Resolució màxima de vídeo fixada a %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1076"/>
+        <location filename="src/MainWindow.cpp" line="1165"/>
         <source>Your privacy is now safe</source>
-        <translation>La seva privacitat ara és segura</translation>
+        <translation>La vostra privacitat ara és segura</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1092"/>
+        <location filename="src/MainWindow.cpp" line="1180"/>
         <source>Downloads complete</source>
         <translation>Baixades completes</translation>
     </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="58"/>
+        <source>&amp;Window</source>
+        <translation>&amp;Finestra</translation>
+    </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="61"/>
+        <source>&amp;Minimize</source>
+        <translation>&amp;Minimitza</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
-        <location filename="src/MediaView.cpp" line="33"/>
+        <location filename="src/MediaView.cpp" line="35"/>
         <source>Most relevant</source>
         <translation>Més rellevant</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="40"/>
+        <location filename="src/MediaView.cpp" line="42"/>
         <source>Most recent</source>
         <translation>Més recent</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="47"/>
+        <location filename="src/MediaView.cpp" line="49"/>
         <source>Most viewed</source>
         <translation>Més vist</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="526"/>
+        <location filename="src/MediaView.cpp" line="521"/>
         <source>You can now paste the YouTube link into another application</source>
-        <translation>Ja pot enganxar l&apos;enllaç de YouTube en una altra aplicació</translation>
+        <translation>Ja podeu enganxar l&apos;enllaç de YouTube en una altra aplicació</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="534"/>
+        <location filename="src/MediaView.cpp" line="529"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>Ja pot enganxar el URL del flux de vídeo en una altra aplicació</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="535"/>
+        <location filename="src/MediaView.cpp" line="530"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>L&apos;enllaç només serà vàlid durant un temps limitat.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="634"/>
+        <location filename="src/MediaView.cpp" line="629"/>
         <source>This is just the demo version of %1.</source>
         <translation>Aquesta només és la versió de demostració del %1.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="635"/>
+        <location filename="src/MediaView.cpp" line="630"/>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation>Li permet probar l&apos;aplicació i veure si li va bé.</translation>
+        <translation>Us permet probar l&apos;aplicació i veure si us va bé.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="665"/>
+        <location filename="src/MediaView.cpp" line="660"/>
         <source>Continue</source>
         <translation>Continua</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="754"/>
+        <location filename="src/MediaView.cpp" line="749"/>
         <source>of</source>
         <comment>Used in video parts, as in '2 of 3'</comment>
         <translation>de</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="766"/>
+        <location filename="src/MediaView.cpp" line="761"/>
         <source>part</source>
         <comment>This is for video parts, as in 'Cool video - part 1'</comment>
         <translation>part</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="768"/>
+        <location filename="src/MediaView.cpp" line="763"/>
         <source>episode</source>
         <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
         <translation>episodi</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="826"/>
+        <location filename="src/MediaView.cpp" line="821"/>
         <source>Sent from %1</source>
         <translation>Enviat des de %1</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="642"/>
+        <location filename="src/MediaView.cpp" line="637"/>
         <source>Get the full version</source>
-        <translation>Aconsegueix la versió completa</translation>
+        <translation>Aconseguiu la versió completa</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="687"/>
+        <location filename="src/MediaView.cpp" line="682"/>
         <source>Downloading %1</source>
         <translation>Baixant %1</translation>
     </message>
@@ -801,7 +825,7 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
-        <location filename="src/playlist/PrettyItemDelegate.cpp" line="156"/>
+        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
         <source>%1 views</source>
         <translation>%1 visualitzacions</translation>
     </message>
@@ -856,61 +880,61 @@
     <message>
         <location filename="src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
-        <translation>Busca</translation>
+        <translation>Cerca</translation>
     </message>
 </context>
 <context>
     <name>SearchView</name>
     <message>
-        <location filename="src/SearchView.cpp" line="74"/>
+        <location filename="src/SearchView.cpp" line="79"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Benvinguts al &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="41"/>
+        <location filename="src/SearchView.cpp" line="46"/>
         <source>Get the full version</source>
         <translation>Aconsegueix la versió completa</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="88"/>
+        <location filename="src/SearchView.cpp" line="93"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
         <translation>Introdueix</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="93"/>
+        <location filename="src/SearchView.cpp" line="98"/>
         <source>a keyword</source>
         <translation>una paraula</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="94"/>
+        <location filename="src/SearchView.cpp" line="99"/>
         <source>a channel</source>
         <translation>un canal</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="99"/>
+        <location filename="src/SearchView.cpp" line="104"/>
         <source>to start watching videos.</source>
         <translation>per comencar a veure vídeos.</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="124"/>
+        <location filename="src/SearchView.cpp" line="128"/>
         <source>Watch</source>
         <translation>Veure</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="142"/>
+        <location filename="src/SearchView.cpp" line="146"/>
         <source>Recent keywords</source>
         <translation>Búsquedes recents</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="160"/>
+        <location filename="src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
         <translation>Canals recents</translation>
     </message>
     <message>
-        <location filename="src/SearchView.h" line="34"/>
+        <location filename="src/SearchView.h" line="26"/>
         <source>Make yourself comfortable</source>
-        <translation>Posi&apos;s còmode</translation>
+        <translation>Poseu-vos còmodes</translation>
     </message>
 </context>
 <context>
