@@ -43,42 +43,27 @@
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="48"/>
-        <source>Report bugs and send in your ideas to %1</source>
-        <translation>Report bugs and send in your ideas to %1</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="52"/>
+        <location filename="src/AboutView.cpp" line="49"/>
         <source>Icon designed by %1.</source>
         <translation>Icon designed by %1.</translation>
     </message>
     <message>
         <location filename="src/AboutView.cpp" line="53"/>
-        <source>Compact mode contributed by %1.</source>
-        <translation>Kompak mode disumbangkan oleh %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="54"/>
-        <source>HTTP proxy support contributed by %1.</source>
-        <translation>dukungan proxy HTTP disumbangkan oleh %1.</translation>
-    </message>
-    <message>
-        <location filename="src/AboutView.cpp" line="58"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Dirilis di bawah &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="src/AboutView.cpp" line="70"/>
+        <location filename="src/AboutView.cpp" line="65"/>
         <source>&amp;Close</source>
         <translation>&amp;Tutup</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="18"/>
+        <location filename="src/AboutView.h" line="25"/>
         <source>About</source>
         <translation>Tentang</translation>
     </message>
     <message>
-        <location filename="src/AboutView.h" line="20"/>
+        <location filename="src/AboutView.h" line="27"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>Apa yang Anda selalu ingin tahu tentang %1 dan tidak pernah berani untuk bertanya</translation>
     </message>
@@ -132,47 +117,47 @@
 <context>
     <name>DownloadItem</name>
     <message>
-        <location filename="src/downloaditem.cpp" line="299"/>
+        <location filename="src/downloaditem.cpp" line="308"/>
         <source>bytes</source>
         <translation>bit</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="302"/>
+        <location filename="src/downloaditem.cpp" line="311"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="305"/>
+        <location filename="src/downloaditem.cpp" line="314"/>
         <source>MB</source>
         <translation>MB</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="321"/>
+        <location filename="src/downloaditem.cpp" line="330"/>
         <source>bytes/sec</source>
         <translation>bit/detik</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="324"/>
+        <location filename="src/downloaditem.cpp" line="333"/>
         <source>KB/sec</source>
         <translation>KB/detik</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="327"/>
+        <location filename="src/downloaditem.cpp" line="336"/>
         <source>MB/sec</source>
         <translation>MB/detik</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="333"/>
+        <location filename="src/downloaditem.cpp" line="342"/>
         <source>seconds</source>
         <translation>detik</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="336"/>
+        <location filename="src/downloaditem.cpp" line="345"/>
         <source>minutes</source>
         <translation>menit</translation>
     </message>
     <message>
-        <location filename="src/downloaditem.cpp" line="339"/>
+        <location filename="src/downloaditem.cpp" line="348"/>
         <source>%4 %5 remaining</source>
         <translation>%4 %5 remaining</translation>
     </message>
@@ -308,22 +293,22 @@
 <context>
     <name>ListModel</name>
     <message>
-        <location filename="src/ListModel.cpp" line="47"/>
+        <location filename="src/ListModel.cpp" line="51"/>
         <source>Searching...</source>
         <translation>Pencarian...</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="48"/>
+        <location filename="src/ListModel.cpp" line="52"/>
         <source>Show %1 More</source>
         <translation>Tampilkan %1 Lebih</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="49"/>
+        <location filename="src/ListModel.cpp" line="53"/>
         <source>No videos</source>
         <translation>Tidak ada video</translation>
     </message>
     <message>
-        <location filename="src/ListModel.cpp" line="50"/>
+        <location filename="src/ListModel.cpp" line="54"/>
         <source>No more videos</source>
         <translation>Tidak ada lagi video</translation>
     </message>
@@ -339,453 +324,492 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="src/MainWindow.cpp" line="125"/>
+        <location filename="src/MainWindow.cpp" line="160"/>
         <source>&amp;Stop</source>
         <translation>&amp;Berhenti</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="126"/>
+        <location filename="src/MainWindow.cpp" line="161"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Stop pemutaran dan kembali ke tampilan pencarian</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="132"/>
+        <location filename="src/MainWindow.cpp" line="179"/>
         <source>S&amp;kip</source>
         <translation>S&amp;kip</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="133"/>
+        <location filename="src/MainWindow.cpp" line="180"/>
         <source>Skip to the next video</source>
         <translation>Lewati ke video berikutnya</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="139"/>
-        <location filename="src/MainWindow.cpp" line="740"/>
+        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="835"/>
         <source>&amp;Pause</source>
         <translation>&amp;Jeda</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="140"/>
-        <location filename="src/MainWindow.cpp" line="741"/>
+        <location filename="src/MainWindow.cpp" line="187"/>
+        <location filename="src/MainWindow.cpp" line="836"/>
         <source>Pause playback</source>
         <translation>Jeda pemutaran</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="146"/>
+        <location filename="src/MainWindow.cpp" line="193"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Layar Penuh</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="147"/>
+        <location filename="src/MainWindow.cpp" line="194"/>
         <source>Go full screen</source>
         <translation>Menuju Layar penuh</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="162"/>
-        <source>&amp;Compact mode</source>
-        <translation>&amp;Kompak mode</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="163"/>
+        <location filename="src/MainWindow.cpp" line="210"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Sembunyikan daftar putar dan toolbar</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="171"/>
-        <source>Open the &amp;YouTube page</source>
-        <translation>Buka the &amp;halaman YouTube</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="172"/>
+        <location filename="src/MainWindow.cpp" line="223"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>Pergi ke halaman video YouTube dan  jeda pemutaran</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="178"/>
-        <source>Copy the YouTube &amp;link</source>
-        <translation>Salin YouTube &amp;link</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="179"/>
+        <location filename="src/MainWindow.cpp" line="230"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>Copy link video YouTube saat ini ke clipboard</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="185"/>
-        <source>Copy the video stream &amp;URL</source>
-        <translation>Salin video stream &amp;URL</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="186"/>
+        <location filename="src/MainWindow.cpp" line="237"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>Copy URL video streaming saat ini ke clipboard</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="192"/>
-        <source>Find video &amp;parts</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="193"/>
+        <location filename="src/MainWindow.cpp" line="244"/>
         <source>Find other video parts hopefully in the right order</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="199"/>
+        <location filename="src/MainWindow.cpp" line="250"/>
         <source>&amp;Remove</source>
         <translation>&amp;Buang</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="200"/>
+        <location filename="src/MainWindow.cpp" line="251"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Hapus video yang dipilih dari daftar main</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="206"/>
+        <location filename="src/MainWindow.cpp" line="257"/>
         <source>Move &amp;Up</source>
         <translation>Pindah &amp;Naik</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="207"/>
+        <location filename="src/MainWindow.cpp" line="258"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Gerakkan ke atas video yang dipilih dalam playlist</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="213"/>
+        <location filename="src/MainWindow.cpp" line="264"/>
         <source>Move &amp;Down</source>
         <translation>Pindah &amp;Turun</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="214"/>
+        <location filename="src/MainWindow.cpp" line="265"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Gerakkan ke atas video yang dipilih dalam playlist</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="220"/>
-        <source>&amp;Clear recent searches</source>
-        <translation>&amp;Bersihkan pencarian saat ini</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="225"/>
+        <location filename="src/MainWindow.cpp" line="276"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>Menghapus sejarah pencarian. Tidak bisa dirampungkan.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="230"/>
+        <location filename="src/MainWindow.cpp" line="281"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quit</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="232"/>
-        <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="233"/>
+        <location filename="src/MainWindow.cpp" line="284"/>
         <source>Bye</source>
         <translation>Bye</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="237"/>
+        <location filename="src/MainWindow.cpp" line="288"/>
         <source>&amp;Website</source>
         <translation>&amp;Website</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="239"/>
+        <location filename="src/MainWindow.cpp" line="290"/>
         <source>%1 on the Web</source>
         <translation>%1 pada Web</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="244"/>
-        <source>Make a &amp;donation</source>
-        <translation>Membuat suatu &amp;sumbangan</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="245"/>
+        <location filename="src/MainWindow.cpp" line="296"/>
         <source>Please support the continued development of %1</source>
         <translation>Harap mendukung kelanjutan pengembangan dari %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="250"/>
+        <location filename="src/MainWindow.cpp" line="301"/>
         <source>&amp;About</source>
         <translation>&amp;About</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="252"/>
+        <location filename="src/MainWindow.cpp" line="303"/>
         <source>Info about %1</source>
         <translation>Info about %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="260"/>
+        <location filename="src/MainWindow.cpp" line="311"/>
         <source>Search</source>
         <translation>Pencarian</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="279"/>
+        <location filename="src/MainWindow.cpp" line="330"/>
         <source>Mute volume</source>
         <translation>Volume bisu</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="281"/>
-        <source>Ctrl+M</source>
-        <translation>Ctrl+M</translation>
-    </message>
-    <message>
-        <location filename="src/MainWindow.cpp" line="312"/>
-        <location filename="src/MainWindow.cpp" line="1091"/>
+        <location filename="src/MainWindow.cpp" line="359"/>
+        <location filename="src/MainWindow.cpp" line="1179"/>
         <source>&amp;Downloads</source>
         <translation>&amp;Unduhan2</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="313"/>
+        <location filename="src/MainWindow.cpp" line="360"/>
         <source>Show details about video downloads</source>
         <translation>Show details about video downloads</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="321"/>
+        <location filename="src/MainWindow.cpp" line="368"/>
         <source>&amp;Download</source>
         <translation>&amp;Download</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="322"/>
+        <location filename="src/MainWindow.cpp" line="369"/>
         <source>Download the current video</source>
         <translation>Download the current video</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="334"/>
+        <location filename="src/MainWindow.cpp" line="381"/>
         <source>Share the current video using %1</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="346"/>
+        <location filename="src/MainWindow.cpp" line="393"/>
         <source>&amp;Email</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="347"/>
+        <location filename="src/MainWindow.cpp" line="394"/>
         <source>Email</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="382"/>
+        <location filename="src/MainWindow.cpp" line="398"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="403"/>
+        <source>&amp;Float on Top</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="408"/>
+        <source>&amp;Stop After This Video</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="445"/>
         <source>&amp;Application</source>
         <translation>&amp;Aplikasi</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="390"/>
+        <location filename="src/MainWindow.cpp" line="447"/>
+        <source>Buy %1...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="458"/>
         <source>&amp;Playback</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="400"/>
+        <location filename="src/MainWindow.cpp" line="472"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Daftar putar</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="407"/>
+        <location filename="src/MainWindow.cpp" line="479"/>
         <source>&amp;Video</source>
         <translation>&amp;Video</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="421"/>
+        <location filename="src/MainWindow.cpp" line="490"/>
         <source>&amp;View</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="427"/>
+        <location filename="src/MainWindow.cpp" line="497"/>
         <source>&amp;Share</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="435"/>
+        <location filename="src/MainWindow.cpp" line="509"/>
         <source>&amp;Help</source>
         <translation>&amp;Menolong</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="520"/>
+        <location filename="src/MainWindow.cpp" line="586"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
         <translation>Press %1 to raise the volume, %2 to lower it</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="669"/>
-        <location filename="src/MainWindow.cpp" line="675"/>
+        <location filename="src/MainWindow.cpp" line="748"/>
+        <location filename="src/MainWindow.cpp" line="754"/>
         <source>Opening %1</source>
         <translation>Membuka %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="688"/>
+        <location filename="src/MainWindow.cpp" line="787"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>Apakah Anda ingin keluar %1 dengan download yang masih berjalan?</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="689"/>
+        <location filename="src/MainWindow.cpp" line="788"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>Jika Anda menutup %1 sekarang, download ini akan dibatalkan.</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="692"/>
+        <location filename="src/MainWindow.cpp" line="793"/>
         <source>Close and cancel download</source>
         <translation>Tutup dan membatalkan download</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="693"/>
+        <location filename="src/MainWindow.cpp" line="794"/>
         <source>Wait for download to finish</source>
         <translation>Menunggu downloadnya selesai</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="854"/>
+        <location filename="src/MainWindow.cpp" line="940"/>
         <source>Leave &amp;Full Screen</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1195"/>
+        <location filename="src/MainWindow.cpp" line="1283"/>
         <source>%1 version %2 is now available.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1201"/>
+        <location filename="src/MainWindow.cpp" line="1297"/>
         <source>Remind me later</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1207"/>
-        <location filename="src/MainWindow.cpp" line="1213"/>
+        <location filename="src/MainWindow.cpp" line="1294"/>
         <source>To get the updated version, download %1 again from the link you received via email and reinstall.</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1216"/>
+        <location filename="src/MainWindow.cpp" line="1301"/>
         <source>Update</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="733"/>
+        <location filename="src/MainWindow.cpp" line="828"/>
         <source>Error: %1</source>
         <translation>Keliru: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="756"/>
+        <location filename="src/MainWindow.cpp" line="169"/>
+        <source>P&amp;revious</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="170"/>
+        <source>Go back to the previous track</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="209"/>
+        <source>&amp;Compact Mode</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="222"/>
+        <source>Open the &amp;YouTube Page</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="229"/>
+        <source>Copy the YouTube &amp;Link</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="236"/>
+        <source>Copy the Video Stream &amp;URL</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="243"/>
+        <source>Find Video &amp;Parts</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="271"/>
+        <source>&amp;Clear Recent Searches</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="295"/>
+        <source>Make a &amp;Donation</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="352"/>
+        <source>&amp;Manually Start Playing</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="353"/>
+        <source>Manually start playing videos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/MainWindow.cpp" line="848"/>
         <source>&amp;Play</source>
         <translation>&amp;Main</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="757"/>
+        <location filename="src/MainWindow.cpp" line="849"/>
         <source>Resume playback</source>
         <translation>Melanjutkan pemutaran</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="964"/>
+        <location filename="src/MainWindow.cpp" line="1055"/>
         <source>Remaining time: %1</source>
         <translation>Sisanya waktu: %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1022"/>
+        <location filename="src/MainWindow.cpp" line="1113"/>
         <source>Volume at %1%</source>
         <translation>Volume pada %1%</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1028"/>
+        <location filename="src/MainWindow.cpp" line="1119"/>
         <source>Volume is muted</source>
         <translation>Volume adalah bisu</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1031"/>
+        <location filename="src/MainWindow.cpp" line="1122"/>
         <source>Volume is unmuted</source>
         <translation>Volume adalah tidak bisu</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1038"/>
+        <location filename="src/MainWindow.cpp" line="1129"/>
         <source>Maximum video definition set to %1</source>
         <translation>Maksimumnya definisi video set ke %1</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1076"/>
+        <location filename="src/MainWindow.cpp" line="1165"/>
         <source>Your privacy is now safe</source>
         <translation>Your privacy is now safe</translation>
     </message>
     <message>
-        <location filename="src/MainWindow.cpp" line="1092"/>
+        <location filename="src/MainWindow.cpp" line="1180"/>
         <source>Downloads complete</source>
         <translation>Downloads komplit</translation>
     </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="58"/>
+        <source>&amp;Window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="local/mac/macsupport.cpp" line="61"/>
+        <source>&amp;Minimize</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
-        <location filename="src/MediaView.cpp" line="33"/>
+        <location filename="src/MediaView.cpp" line="35"/>
         <source>Most relevant</source>
         <translation>Paling relevan</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="40"/>
+        <location filename="src/MediaView.cpp" line="42"/>
         <source>Most recent</source>
         <translation>Terbanyak saat ini</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="47"/>
+        <location filename="src/MediaView.cpp" line="49"/>
         <source>Most viewed</source>
         <translation>Most viewed</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="526"/>
+        <location filename="src/MediaView.cpp" line="521"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>Sekarang Anda dapat paste link YouTube ke dalam aplikasi lain</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="534"/>
+        <location filename="src/MediaView.cpp" line="529"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>Anda sekarang dapat menempelkan video stream URL ke dalam aplikasi lain</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="535"/>
+        <location filename="src/MediaView.cpp" line="530"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>The link will be valid only for a limited time.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="634"/>
+        <location filename="src/MediaView.cpp" line="629"/>
         <source>This is just the demo version of %1.</source>
         <translation>Ini hanya versi demo dari %1.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="635"/>
+        <location filename="src/MediaView.cpp" line="630"/>
         <source>It allows you to test the application and see if it works for you.</source>
         <translation>Ini memungkinkan Anda untuk menguji aplikasi dan melihat apakah ia bekerja untuk Anda.</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="665"/>
+        <location filename="src/MediaView.cpp" line="660"/>
         <source>Continue</source>
         <translation>Berlanjut</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="754"/>
+        <location filename="src/MediaView.cpp" line="749"/>
         <source>of</source>
         <comment>Used in video parts, as in '2 of 3'</comment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="766"/>
+        <location filename="src/MediaView.cpp" line="761"/>
         <source>part</source>
         <comment>This is for video parts, as in 'Cool video - part 1'</comment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="768"/>
+        <location filename="src/MediaView.cpp" line="763"/>
         <source>episode</source>
         <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="826"/>
+        <location filename="src/MediaView.cpp" line="821"/>
         <source>Sent from %1</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="642"/>
+        <location filename="src/MediaView.cpp" line="637"/>
         <source>Get the full version</source>
         <translation>Dapatkan versi komplit</translation>
     </message>
     <message>
-        <location filename="src/MediaView.cpp" line="687"/>
+        <location filename="src/MediaView.cpp" line="682"/>
         <source>Downloading %1</source>
         <translation>Mengunduh %1</translation>
     </message>
@@ -801,7 +825,7 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
-        <location filename="src/playlist/PrettyItemDelegate.cpp" line="156"/>
+        <location filename="src/playlist/PrettyItemDelegate.cpp" line="170"/>
         <source>%1 views</source>
         <translation>%1 views</translation>
     </message>
@@ -862,53 +886,53 @@
 <context>
     <name>SearchView</name>
     <message>
-        <location filename="src/SearchView.cpp" line="74"/>
+        <location filename="src/SearchView.cpp" line="79"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Selamat datang ke &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="41"/>
+        <location filename="src/SearchView.cpp" line="46"/>
         <source>Get the full version</source>
         <translation>Dapatkan versi lengkap</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="88"/>
+        <location filename="src/SearchView.cpp" line="93"/>
         <source>Enter</source>
         <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
         <translation>Enter</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="93"/>
+        <location filename="src/SearchView.cpp" line="98"/>
         <source>a keyword</source>
         <translation>suatu kata kunci</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="94"/>
+        <location filename="src/SearchView.cpp" line="99"/>
         <source>a channel</source>
         <translation>suatu saluran</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="99"/>
+        <location filename="src/SearchView.cpp" line="104"/>
         <source>to start watching videos.</source>
         <translation>Untuk memulai menonton video-video.</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="124"/>
+        <location filename="src/SearchView.cpp" line="128"/>
         <source>Watch</source>
         <translation>Menonton</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="142"/>
+        <location filename="src/SearchView.cpp" line="146"/>
         <source>Recent keywords</source>
         <translation>Kata kunci saat ini</translation>
     </message>
     <message>
-        <location filename="src/SearchView.cpp" line="160"/>
+        <location filename="src/SearchView.cpp" line="159"/>
         <source>Recent channels</source>
         <translation>Saluran </translation>
     </message>
     <message>
-        <location filename="src/SearchView.h" line="34"/>
+        <location filename="src/SearchView.h" line="26"/>
         <source>Make yourself comfortable</source>
         <translation>Membuat dirimu nyaman</translation>
     </message>
